==> haskell-tamarin-prover-theory-1.10.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-theory.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-theory
version:              1.10.0
visibility:           public
id:                   tamarin-prover-theory-1.10.0-8xe5IbpopZMB8NrUYB61jQ
key:                  tamarin-prover-theory-1.10.0-8xe5IbpopZMB8NrUYB61jQ
license:              LicenseRef-GPL
copyright:
    Benedikt Schmidt, Simon Meier, Cas Cremers, Jannik Dreier, Ralf Sasse, 2010-2023

maintainer:
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>
    Cas Cremers <cremers@cispa.de>

author:
    Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
    Simon Meier <simon.meier@inf.ethz.ch>,
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Security protocol types and constraint solver library for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides the types to represent security
    protocols, and it implements the constraint solver.

category:             Theorem Provers
abi:                  e9758002c32cf6b199f9087b233fa17a
exposed:              True
exposed-modules:
    ClosedTheory Items.AccLemmaItem Items.CaseTestItem Items.ExportInfo
    Items.LemmaItem Items.OpenTheoryItem Items.OptionItem
    Items.ProcessItem Items.RuleItem Items.TheoryItem Lemma OpenTheory
    Pretty Prover Rule Theory Theory.Constraint.Solver
    Theory.Constraint.Solver.AnnotatedGoals
    Theory.Constraint.Solver.Contradictions
    Theory.Constraint.Solver.Goals Theory.Constraint.Solver.ProofMethod
    Theory.Constraint.Solver.Reduction
    Theory.Constraint.Solver.Simplify Theory.Constraint.Solver.Sources
    Theory.Constraint.System Theory.Constraint.System.Constraints
    Theory.Constraint.System.Dot
    Theory.Constraint.System.Graph.Abbreviation
    Theory.Constraint.System.Graph.Graph
    Theory.Constraint.System.Graph.GraphRepr
    Theory.Constraint.System.Graph.Simplification
    Theory.Constraint.System.Guarded Theory.Constraint.System.JSON
    Theory.Model Theory.Model.Atom Theory.Model.Fact
    Theory.Model.Formula Theory.Model.Restriction Theory.Model.Rule
    Theory.Model.Signature Theory.Module Theory.Proof
    Theory.ProofSkeleton Theory.Sapic Theory.Sapic.Annotation
    Theory.Sapic.Pattern Theory.Sapic.Position Theory.Sapic.Print
    Theory.Sapic.Process Theory.Sapic.Term Theory.Text.Parser
    Theory.Text.Parser.Macro Theory.Text.Parser.Restriction
    Theory.Text.Parser.Signature Theory.Text.Parser.Token
    Theory.Text.Pretty Theory.Tools.AbstractInterpretation
    Theory.Tools.EquationStore Theory.Tools.InjectiveFactInstances
    Theory.Tools.IntruderRules Theory.Tools.LoopBreakers
    Theory.Tools.MessageDerivationChecks Theory.Tools.RuleVariants
    Theory.Tools.SubtermStore Theory.Tools.Wellformedness TheoryObject

hidden-modules:
    Theory.Syntactic.Predicate Theory.Text.Parser.Accountability
    Theory.Text.Parser.Exceptions Theory.Text.Parser.Fact
    Theory.Text.Parser.Formula Theory.Text.Parser.Lemma
    Theory.Text.Parser.Let Theory.Text.Parser.Proof
    Theory.Text.Parser.Rule Theory.Text.Parser.Sapic
    Theory.Text.Parser.Tactics Theory.Text.Parser.Term
    Theory.Sapic.PlainProcess Theory.Sapic.Substitution

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tamarin-prover-theory-1.10.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tamarin-prover-theory-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-theory
hs-libraries:         HStamarin-prover-theory-1.10.0-8xe5IbpopZMB8NrUYB61jQ
depends:
    aeson-2.1.2.1-5xA96pEAe1OF80YjsNpBtK
    aeson-pretty-0.8.10-1dlwPC4Gr0U23GIUJQ9AUw array-0.5.4.0
    attoparsec-0.14.4-7XtEyfF24RF27dz6MIAdRK base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    exceptions-0.10.4 fclabels-2.0.5.1-FImK52swWA5JqZ1RvP2cAM
    filepath-1.4.2.2 mtl-2.2.2 parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1
    parsec-3.1.15.0 pretty-1.1.3.6 process-1.6.16.0
    regex-pcre-0.95.0.0-8JTNevh6vF7HTkboxZ55oR
    regex-posix-0.96.0.1-Genc39RUTH74GYzEFB6fWq
    safe-0.3.21-DycKuNeB2NrH0Uhgd9RWtv
    split-0.2.5-3yHGsS1jHoyLHpkVbnU0Aa
    tamarin-prover-term-1.10.0-LrbSmdpmoz9ByTmGaItRxI
    tamarin-prover-utils-1.10.0-7HZI8eZ2TEXAIeVQaJE4dm text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-11xJxnG7KzmIv2px8kQrrx

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-theory/html/tamarin-prover-theory.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-theory/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-theory-1.10.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-theory.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-theory
version:              1.10.0
visibility:           public
id:                   tamarin-prover-theory-1.10.0-7FndyelUhOiEv0gbTgsfeA
key:                  tamarin-prover-theory-1.10.0-7FndyelUhOiEv0gbTgsfeA
license:              LicenseRef-GPL
copyright:
    Benedikt Schmidt, Simon Meier, Cas Cremers, Jannik Dreier, Ralf Sasse, 2010-2023

maintainer:
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>
    Cas Cremers <cremers@cispa.de>

author:
    Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
    Simon Meier <simon.meier@inf.ethz.ch>,
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Security protocol types and constraint solver library for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides the types to represent security
    protocols, and it implements the constraint solver.

category:             Theorem Provers
abi:                  cebca8f8b7ad2ab21d16c5b308923697
exposed:              True
exposed-modules:
    ClosedTheory Items.AccLemmaItem Items.CaseTestItem Items.ExportInfo
    Items.LemmaItem Items.OpenTheoryItem Items.OptionItem
    Items.ProcessItem Items.RuleItem Items.TheoryItem Lemma OpenTheory
    Pretty Prover Rule Theory Theory.Constraint.Solver
    Theory.Constraint.Solver.AnnotatedGoals
    Theory.Constraint.Solver.Contradictions
    Theory.Constraint.Solver.Goals Theory.Constraint.Solver.ProofMethod
    Theory.Constraint.Solver.Reduction
    Theory.Constraint.Solver.Simplify Theory.Constraint.Solver.Sources
    Theory.Constraint.System Theory.Constraint.System.Constraints
    Theory.Constraint.System.Dot
    Theory.Constraint.System.Graph.Abbreviation
    Theory.Constraint.System.Graph.Graph
    Theory.Constraint.System.Graph.GraphRepr
    Theory.Constraint.System.Graph.Simplification
    Theory.Constraint.System.Guarded Theory.Constraint.System.JSON
    Theory.Model Theory.Model.Atom Theory.Model.Fact
    Theory.Model.Formula Theory.Model.Restriction Theory.Model.Rule
    Theory.Model.Signature Theory.Module Theory.Proof
    Theory.ProofSkeleton Theory.Sapic Theory.Sapic.Annotation
    Theory.Sapic.Pattern Theory.Sapic.Position Theory.Sapic.Print
    Theory.Sapic.Process Theory.Sapic.Term Theory.Text.Parser
    Theory.Text.Parser.Macro Theory.Text.Parser.Restriction
    Theory.Text.Parser.Signature Theory.Text.Parser.Token
    Theory.Text.Pretty Theory.Tools.AbstractInterpretation
    Theory.Tools.EquationStore Theory.Tools.InjectiveFactInstances
    Theory.Tools.IntruderRules Theory.Tools.LoopBreakers
    Theory.Tools.MessageDerivationChecks Theory.Tools.RuleVariants
    Theory.Tools.SubtermStore Theory.Tools.Wellformedness TheoryObject

hidden-modules:
    Theory.Syntactic.Predicate Theory.Text.Parser.Accountability
    Theory.Text.Parser.Exceptions Theory.Text.Parser.Fact
    Theory.Text.Parser.Formula Theory.Text.Parser.Lemma
    Theory.Text.Parser.Let Theory.Text.Parser.Proof
    Theory.Text.Parser.Rule Theory.Text.Parser.Sapic
    Theory.Text.Parser.Tactics Theory.Text.Parser.Term
    Theory.Sapic.PlainProcess Theory.Sapic.Substitution

import-dirs:          /usr/lib/ghc-9.2.8/site-local/tamarin-prover-theory-1.10.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tamarin-prover-theory-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-theory
hs-libraries:         HStamarin-prover-theory-1.10.0-7FndyelUhOiEv0gbTgsfeA
depends:
    aeson-2.1.2.1-IkP1OjeNuTxglWxWeIvI9
    aeson-pretty-0.8.10-5TSYkD8Co5LLMI8e0zAoII array-0.5.4.0
    attoparsec-0.14.4-IUoeEKVn7Gr6GqDDI9lyTI base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    exceptions-0.10.4 fclabels-2.0.5.1-96ZFMVq0dg55C714LDpDTT
    filepath-1.4.2.2 mtl-2.2.2 parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1
    parsec-3.1.15.0 pretty-1.1.3.6 process-1.6.16.0
    regex-pcre-0.95.0.0-8JTNevh6vF7HTkboxZ55oR
    regex-posix-0.96.0.1-Genc39RUTH74GYzEFB6fWq
    safe-0.3.21-41ZPWazUMNgR08x0DBIts
    split-0.2.5-D8Q5hs7UAOeFSfUt4jgpO4
    tamarin-prover-term-1.10.0-ASJ3tROaItBKVYmkCtQtCX
    tamarin-prover-utils-1.10.0-9iuWEDNjyrm4QOFQNH0mjZ text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-CbgRsq6vXtfJZv6A35mNTh

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-theory/html/tamarin-prover-theory.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-theory/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
